#ifndef __DILLO_H__
#define __DILLO_H__

#include "browser.h"
#include "web.h"

#define DILLO_HOME "http://dillo.cipsga.org.br/"

#endif /* __DILLO_H__ */
